package com.jjt.ws.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.ws.domain.TwinWorkshop;
import com.jjt.ws.domain.TwinWorkshopEnergy;

/**
 * 车间管理Mapper接口
 *
 * @author wukai
 * @date 2025-01-17
 */
public interface TwinWorkshopMapper extends BaseMapper<TwinWorkshop>
{
    /**
     * 查询车间管理
     *
     * @param wsId 车间管理主键
     * @return 车间管理
     */
    public TwinWorkshop selectTwinWorkshopByWsId(Long wsId);

    /**
     * 查询车间管理列表
     *
     * @param twinWorkshop 车间管理
     * @return 车间管理集合
     */
    public List<TwinWorkshop> selectTwinWorkshopList(TwinWorkshop twinWorkshop);

    /**
     * 新增车间管理
     *
     * @param twinWorkshop 车间管理
     * @return 结果
     */
    public int insertTwinWorkshop(TwinWorkshop twinWorkshop);

    /**
     * 修改车间管理
     *
     * @param twinWorkshop 车间管理
     * @return 结果
     */
    public int updateTwinWorkshop(TwinWorkshop twinWorkshop);

    /**
     * 删除车间管理
     *
     * @param wsId 车间管理主键
     * @return 结果
     */
    public int deleteTwinWorkshopByWsId(Long wsId);

    /**
     * 批量删除车间管理
     *
     * @param wsIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinWorkshopByWsIds(Long[] wsIds);

    /**
     * 批量删除车间能源管理
     *
     * @param wsIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinWorkshopEnergyByWsIds(Long[] wsIds);

    /**
     * 批量新增车间能源管理
     *
     * @param twinWorkshopEnergyList 车间能源管理列表
     * @return 结果
     */
    public int batchTwinWorkshopEnergy(List<TwinWorkshopEnergy> twinWorkshopEnergyList);


    /**
     * 通过车间管理主键删除车间能源管理信息
     *
     * @param wsId 车间管理ID
     * @return 结果
     */
    public int deleteTwinWorkshopEnergyByWsId(Long wsId);

    /**
     * 查询车间管理
     *
     * @param wsCode 车间编码
     * @return 车间管理
     */
    TwinWorkshop selectTwinWorkshopByWsCode(String wsCode);
}
